@@ -104,15 +104,33 @@ time_t last_update_time(GSList *object){
 	return 0;
 
     strptime(item_value(object, "last_update"), "%D %I:%M", &tm);
+    tm.tm_isdst = 1;
     last_update = mktime(&tm);
 
     /* Add 12 hours if  date have PM field */
     if(strstr(item_value(object, "last_update"), "PM"))
 	last_update += 12 * 3600;
 
-    last_update -= 3600; /* TODO. I don't understand why this is needed. */
+//    last_update -= 3600; /* TODO. I don't understand why this is needed. */
     return last_update;
 }
+time_t calculate_diff_time(int timezone){
+
+    time_t	current_time,
+                diff_time = 0,
+                utc_time;
+    struct tm	*gmt;
+    
+    current_time = time(NULL); /* get current day */
+     /* set Daylight */
+    gmt = gmtime(&current_time);
+    gmt->tm_isdst = 1;
+    /* correct time for current location */
+    utc_time = mktime(gmt);
+    diff_time = utc_time - current_time  + 60 * 60 * timezone;
+
+    return diff_time;
+}
 /*******************************************************************************/
 #ifndef RELEASE
 void display_all_object_items(GSList *object){
