@@ -572,7 +572,7 @@ void weather_buttons_fill(gboolean check_error){
 						    (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units]));
 			}else{
 			        memset(app->forecast_string, 0, sizeof(app->forecast_string));
-				strcat(app->forecast_string, item_value(wcs.day_data[i + j], "night_title"));
+				strcat(app->forecast_string, (char*)hash_table_find(item_value(wcs.day_data[i + j],"night_title")));
 				strcat(app->forecast_string, _("\nHumidity: "));
 				if(strcmp(item_value(wcs.day_data[i + j], "night_humidity"), "N/A"))
 				    sprintf(app->forecast_string + strlen(app->forecast_string), "%s%%\n",
