@@ -64,7 +64,6 @@ gboolean show_popup_window_handler(GtkWidget *widget, GdkEvent *event,
 
     int		i, k;
     time_t	current_time = 0,
-		utc_time,
 		diff_time,
 		current_data_last_update = 0;
     GtkWidget	*popup_frame = NULL,
@@ -118,9 +117,9 @@ gboolean show_popup_window_handler(GtkWidget *widget, GdkEvent *event,
 
     /* prepare time additioanal value */
     current_time = time(NULL); /* get current day */
-    /* correct time for current location */
-    utc_time = mktime(gmtime(&current_time));
-    diff_time = utc_time - current_time  + 60 * 60 * atol(item_value(wcs.day_data[i], "station_time_zone"));
+    
+    diff_time =  calculate_diff_time(atol(item_value(wcs.day_data[i], "station_time_zone")));
+
     #ifndef RELEASE
     fprintf(stderr, "\n>>>>>>>Diff time=%li<<<<<<\n", diff_time);
     #endif
